# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: plugin.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from robomotion import struct_pb2 as struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0cplugin.proto\x12\x05proto\x1a\x0cstruct.proto"2\n\x05\x45rror\x12\n\n\x02OK\x18\x02 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t"1\n\x0bInitRequest\x12\x14\n\x0c\x65vent_server\x18\x01 \x01(\r\x12\x0c\n\x04port\x18\x02 \x01(\r"/\n\x0fOnCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x0c"/\n\x10OnCreateResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error"3\n\x10OnMessageRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x11\n\tinMessage\x18\x02 \x01(\x0c"D\n\x11OnMessageResponse\x12\x12\n\noutMessage\x18\x01 \x01(\x0c\x12\x1b\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0c.proto.Error"\x1e\n\x0eOnCloseRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t".\n\x0fOnCloseResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error"\x07\n\x05\x45mpty";\n\x0c\x44\x65\x62ugRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\x0c"2\n\x14\x45mitFlowEventRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"/\n\x10\x45mitInputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\x0c"?\n\x11\x45mitOutputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\x0c\x12\x0c\n\x04port\x18\x03 \x01(\x05"?\n\x10\x45mitErrorRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t"6\n\x13GetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t"=\n\x14GetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"D\n\x13SetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c"=\n\x14SetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"\'\n\x08Variable\x12\r\n\x05scope\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"7\n\x12GetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable"=\n\x13GetVariableResponse\x12&\n\x05value\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"_\n\x12SetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct">\n\x14GetRobotInfoResponse\x12&\n\x05robot\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"5\n\x11\x41ppRequestRequest\x12\x0f\n\x07request\x18\x01 \x01(\x0c\x12\x0f\n\x07timeout\x18\x02 \x01(\x05"&\n\x12\x41ppRequestResponse\x12\x10\n\x08response\x18\x01 \x01(\x0c"0\n\x13\x44ownloadFileRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t2\xe7\x01\n\x04Node\x12(\n\x04Init\x12\x12.proto.InitRequest\x1a\x0c.proto.Empty\x12;\n\x08OnCreate\x12\x16.proto.OnCreateRequest\x1a\x17.proto.OnCreateResponse\x12>\n\tOnMessage\x12\x17.proto.OnMessageRequest\x1a\x18.proto.OnMessageResponse\x12\x38\n\x07OnClose\x12\x15.proto.OnCloseRequest\x1a\x16.proto.OnCloseResponse2\x82\x06\n\rRuntimeHelper\x12#\n\x05\x43lose\x12\x0c.proto.Empty\x1a\x0c.proto.Empty\x12*\n\x05\x44\x65\x62ug\x12\x13.proto.DebugRequest\x1a\x0c.proto.Empty\x12:\n\rEmitFlowEvent\x12\x1b.proto.EmitFlowEventRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitInput\x12\x17.proto.EmitInputRequest\x1a\x0c.proto.Empty\x12\x34\n\nEmitOutput\x12\x18.proto.EmitOutputRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitError\x12\x17.proto.EmitErrorRequest\x1a\x0c.proto.Empty\x12G\n\x0cGetVaultItem\x12\x1a.proto.GetVaultItemRequest\x1a\x1b.proto.GetVaultItemResponse\x12G\n\x0cSetVaultItem\x12\x1a.proto.SetVaultItemRequest\x1a\x1b.proto.SetVaultItemResponse\x12\x44\n\x0bGetVariable\x12\x19.proto.GetVariableRequest\x1a\x1a.proto.GetVariableResponse\x12\x36\n\x0bSetVariable\x12\x19.proto.SetVariableRequest\x1a\x0c.proto.Empty\x12\x39\n\x0cGetRobotInfo\x12\x0c.proto.Empty\x1a\x1b.proto.GetRobotInfoResponse\x12\x41\n\nAppRequest\x12\x18.proto.AppRequestRequest\x1a\x19.proto.AppRequestResponse\x12\x38\n\x0c\x44ownloadFile\x12\x1a.proto.DownloadFileRequest\x1a\x0c.proto.Emptyb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "plugin_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _ERROR._serialized_start = 37
    _ERROR._serialized_end = 87
    _INITREQUEST._serialized_start = 89
    _INITREQUEST._serialized_end = 138
    _ONCREATEREQUEST._serialized_start = 140
    _ONCREATEREQUEST._serialized_end = 187
    _ONCREATERESPONSE._serialized_start = 189
    _ONCREATERESPONSE._serialized_end = 236
    _ONMESSAGEREQUEST._serialized_start = 238
    _ONMESSAGEREQUEST._serialized_end = 289
    _ONMESSAGERESPONSE._serialized_start = 291
    _ONMESSAGERESPONSE._serialized_end = 359
    _ONCLOSEREQUEST._serialized_start = 361
    _ONCLOSEREQUEST._serialized_end = 391
    _ONCLOSERESPONSE._serialized_start = 393
    _ONCLOSERESPONSE._serialized_end = 439
    _EMPTY._serialized_start = 441
    _EMPTY._serialized_end = 448
    _DEBUGREQUEST._serialized_start = 450
    _DEBUGREQUEST._serialized_end = 509
    _EMITFLOWEVENTREQUEST._serialized_start = 511
    _EMITFLOWEVENTREQUEST._serialized_end = 561
    _EMITINPUTREQUEST._serialized_start = 563
    _EMITINPUTREQUEST._serialized_end = 610
    _EMITOUTPUTREQUEST._serialized_start = 612
    _EMITOUTPUTREQUEST._serialized_end = 675
    _EMITERRORREQUEST._serialized_start = 677
    _EMITERRORREQUEST._serialized_end = 740
    _GETVAULTITEMREQUEST._serialized_start = 742
    _GETVAULTITEMREQUEST._serialized_end = 796
    _GETVAULTITEMRESPONSE._serialized_start = 798
    _GETVAULTITEMRESPONSE._serialized_end = 859
    _SETVAULTITEMREQUEST._serialized_start = 861
    _SETVAULTITEMREQUEST._serialized_end = 929
    _SETVAULTITEMRESPONSE._serialized_start = 931
    _SETVAULTITEMRESPONSE._serialized_end = 992
    _VARIABLE._serialized_start = 994
    _VARIABLE._serialized_end = 1033
    _GETVARIABLEREQUEST._serialized_start = 1035
    _GETVARIABLEREQUEST._serialized_end = 1090
    _GETVARIABLERESPONSE._serialized_start = 1092
    _GETVARIABLERESPONSE._serialized_end = 1153
    _SETVARIABLEREQUEST._serialized_start = 1155
    _SETVARIABLEREQUEST._serialized_end = 1250
    _GETROBOTINFORESPONSE._serialized_start = 1252
    _GETROBOTINFORESPONSE._serialized_end = 1314
    _APPREQUESTREQUEST._serialized_start = 1316
    _APPREQUESTREQUEST._serialized_end = 1369
    _APPREQUESTRESPONSE._serialized_start = 1371
    _APPREQUESTRESPONSE._serialized_end = 1409
    _DOWNLOADFILEREQUEST._serialized_start = 1411
    _DOWNLOADFILEREQUEST._serialized_end = 1459
    _NODE._serialized_start = 1462
    _NODE._serialized_end = 1693
    _RUNTIMEHELPER._serialized_start = 1696
    _RUNTIMEHELPER._serialized_end = 2466
# @@protoc_insertion_point(module_scope)
